# Primeight

Cassandra is a database system that provides scalability, high availability,
and fault tolerance.

This repository contains our Python library designed to interact with Cassandra.
`primeight` is packaged with all you need to create tables, query them, and insert data into your database. 

### Notes

If you find a bug, would like to suggest a new feature or even would like to suggest some change, please open an issue.

### References

* [Cassandra docs](http://cassandra.apache.org/doc/latest/)
